==> apache-camel-quarkus-2.9.0-src.zip: camel-quarkus-2.9.0/integration-test-groups/foundation/bean/src/main/java/org/apache/camel/quarkus/component/bean/method/Producers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.bean.method;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;

import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.inject.Produces;
import javax.inject.Named;

public class Producers {

    @Produces
    @ApplicationScoped
    @Named("collected-names")
    public Map<String, List<String>> collectedNames() {
        Map<String, List<String>> result = new HashMap<>();
        result.put("beanFromRegistryByName", new CopyOnWriteArrayList<>());
        result.put("beanByClassName", new CopyOnWriteArrayList<>());
        result.put("beanInstance", new CopyOnWriteArrayList<>());
        return result;
    }
}

==> apache-camel-quarkus-3.27.0-src.zip: camel-quarkus-3.27.0/integration-test-groups/foundation/bean/src/main/java/org/apache/camel/quarkus/component/bean/method/Producers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.bean.method;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Named;

public class Producers {

    @Produces
    @ApplicationScoped
    @Named("collected-names")
    public Map<String, List<String>> collectedNames() {
        Map<String, List<String>> result = new HashMap<>();
        result.put("beanFromRegistryByName", new CopyOnWriteArrayList<>());
        result.put("beanByClassName", new CopyOnWriteArrayList<>());
        result.put("beanInstance", new CopyOnWriteArrayList<>());
        return result;
    }
}
